#ifndef NT2_INCLUDE_FUNCTIONS_MAX_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MAX_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/max.hpp>

#endif
